aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/fo
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/org/apache/fop/fo')
-rw-r--r--src/java/org/apache/fop/fo/expr/PropertyParser.java6
-rw-r--r--src/java/org/apache/fop/fo/properties/LengthProperty.java2
2 files changed, 4 insertions, 4 deletions
diff --git a/src/java/org/apache/fop/fo/properties/LengthProperty.java b/src/java/org/apache/fop/fo/properties/LengthProperty.java
index 4ffe38074..16bbe430c 100644
--- a/src/java/org/apache/fop/fo/properties/LengthProperty.java
+++ b/src/java/org/apache/fop/fo/properties/LengthProperty.java
@@ -59,7 +59,7 @@ public abstract class LengthProperty extends Property
//Assume pixels (like in HTML) when there's no unit
return FixedLength.getInstance(
p.getNumeric().getNumericValue(), "px",
- propertyList.getFObj().getUserAgent().getSourceResolution() / 72.0f);
+ propertyList.getFObj().getUserAgent().getTargetResolution() / 72.0f);
}
Length val = p.getLength();
if (val != null) {
diff --git a/src/java/org/apache/fop/fo/expr/PropertyParser.java b/src/java/org/apache/fop/fo/expr/PropertyParser.java
index 7ae1db7f3..4f1cdbdc6 100644
--- a/src/java/org/apache/fop/fo/expr/PropertyParser.java
+++ b/src/java/org/apache/fop/fo/expr/PropertyParser.java
@@ -99,7 +99,7 @@ public final class PropertyParser extends PropertyTokenizer {
/**
* Private constructor. Called by the static parse() method.
* @param propExpr The specified value (attribute on the xml element).
- * @param propInfo A PropertyInfo object representing the context in
+ * @param pInfo A PropertyInfo object representing the context in
* which the property expression is to be evaluated.
*/
private PropertyParser(String propExpr, PropertyInfo pInfo) {
@@ -310,12 +310,12 @@ public final class PropertyParser extends PropertyTokenizer {
propInfo.currentFontSize());
} else {
if ("px".equals(unitPart)) {
//pass the ratio between source-resolution and
//the default resolution of 72dpi
prop = FixedLength.getInstance(
numPart, unitPart,
propInfo.getPropertyList().getFObj()
- .getUserAgent().getSourceResolution() / 72.0f);
+ .getUserAgent().getTargetResolution() / 72.0f);
} else {
//use default resolution of 72dpi
prop = FixedLength.getInstance(numPart, unitPart);
@@ -310,12 +310,12 @@ public final class PropertyParser extends PropertyTokenizer {
} else {
if ("px".equals(unitPart)) {
- //pass the ratio between source-resolution and
+ //pass the ratio between target-resolution and
//the default resolution of 72dpi
prop = FixedLength.getInstance(